@@ -22,6 +22,9 @@ class DatabaseSchemaEditor(MySqlDatabaseSchemaEditor, ABC):
         # 生成sql
         sql, params = super().column_sql(model, field, include_default)
 
+        if not isinstance(sql, str):
+            return sql, params
+
         # 写入字段注释
         if field.help_text:
             sql += " COMMENT '%s'" % field.help_text
